@@ -24,6 +24,7 @@
 #include <libgnome/libgnome.h>
 #include <gtk/gtk.h>
 #include "gconf-utils.h"
+#include "file-utils.h"
 
 
 #define REQUEST_ENTRY_WIDTH 220
@@ -120,6 +121,8 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	int           response_id;
 	char         *escaped_message, *markup_text;
 
+	g_return_val_if_fail (message != NULL, NULL);
+
 	if (stock_id == NULL)
 		stock_id = GTK_STOCK_DIALOG_INFO;
 
@@ -465,20 +468,21 @@ _gtk_error_dialog_from_gerror_run (GtkWindow        *parent,
 	GtkWidget *d;
 
 	g_return_if_fail (*gerror != NULL);
+	g_return_if_fail ((*gerror)->message != NULL);
 
-	d = _gtk_message_dialog_new (parent,
-				     GTK_DIALOG_MODAL,
-				     GTK_STOCK_DIALOG_ERROR,
-				     (*gerror)->message,
-				     NULL,
-				     GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
-				     NULL);
-
-	g_signal_connect (G_OBJECT (d), "response",
-			  G_CALLBACK (gtk_widget_destroy),
-			  NULL);
-
-	gtk_widget_show (d);
+	if ((*gerror)->message != NULL) {
+		d = _gtk_message_dialog_new (parent,
+					     GTK_DIALOG_MODAL,
+					     GTK_STOCK_DIALOG_ERROR,
+					     (*gerror)->message,
+					     NULL,
+					     GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
+					     NULL);
+		g_signal_connect (G_OBJECT (d), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+		gtk_widget_show (d);
+	}
 
 	g_clear_error (gerror);
 }
@@ -666,3 +670,34 @@ _gtk_label_get_filename_text (GtkLabel   *label)
 
 	return text;
 }
+
+
+gboolean
+exec_command (const char *application, 
+	      GList      *file_list)
+{
+        GString *command;
+        GList   *scan;
+	GError  *err = NULL;
+	gboolean error;
+
+	command = g_string_new ("");
+	g_string_append (command, application);
+        for (scan = file_list; scan; scan = scan->next) {
+		char *filename = scan->data;
+		char *e_filename;
+
+		g_string_append_c (command, ' ');
+		e_filename = shell_escape (filename);
+		g_string_append (command, e_filename);
+
+		g_free (e_filename);
+        }
+
+	error = (! g_spawn_command_line_async (command->str, &err) || (err != NULL));
+	if (error)
+		_gtk_error_dialog_from_gerror_run (NULL, &err);
+	g_string_free (command, TRUE);
+
+	return ! error;
+}
